module.exports = defineTest({
	description: 'removes arguments that correspond to unused parameters'
});
